@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,19 +7,20 @@
 #ifndef TEXTFINDREPLACEWIDGET_H
 #define TEXTFINDREPLACEWIDGET_H
 
-#include <QWidget>
 #include <QTextDocument>
+#include <QWidget>
 
 class QAction;
 class QLineEdit;
 class QPushButton;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class TextFindWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit TextFindWidget(QWidget *parent = nullptr);
-    ~TextFindWidget();
+    ~TextFindWidget() override;
 
     Q_REQUIRED_RESULT QTextDocument::FindFlags searchOptions() const;
 
